.. BuildGrid documentation master file, created by
   sphinx-quickstart on Tue Aug 14 16:51:30 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


BuildGrid's documentation
=========================

Remote execution service implementing Google's Remote Execution API and Remote Worker API.

.. toctree::
   :maxdepth: 1
   :caption: Using BuildGrid

   user/about.rst
   user/components.rst
   user/getting_started.rst
   user/installation.rst
   user/configuration.rst
   user/using.rst
   user/monitoring.rst
   user/resources.rst
   user/reference_cli.rst

.. toctree::
   :maxdepth: 1
   :caption: Developing BuildGrid

   developer/installation_developer.rst
   developer/notes_for_developers.rst
   developer/reference_api.rst
   developer/contributing.rst
   developer/architecture.rst


Resources
---------

- `Homepage`_
- `GitLab repository`_
- `Bug tracking`_
- `Mailing list`_
- `Slack channel`_ [`invite link`_]

.. _Homepage: https://buildgrid.build
.. _GitLab repository: https://gitlab.com/BuildGrid/buildgrid
.. _Bug tracking: https://gitlab.com/BuildGrid/buildgrid/boards
.. _Mailing list: https://lists.buildgrid.build/cgi-bin/mailman/listinfo/buildgrid
.. _Slack channel: https://buildteamworld.slack.com/messages/CC9MKC203
.. _invite link: https://join.slack.com/t/buildteamworld/shared_invite/zt-4zy8f5j5-KwiJuBoAAUorB_mdQHwF7Q
